@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 #
 # This file is part of urlwatch (https://thp.io/2008/urlwatch/).
-# Copyright (c) 2008-2016 Thomas Perl <thp.io/about>
+# Copyright (c) 2008-2018 Thomas Perl <m@thp.io>
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -31,6 +31,7 @@
 import smtplib
 import getpass
 import subprocess
+import logging
 
 try:
     import keyring
@@ -41,13 +42,15 @@ import email.mime.multipart
 import email.mime.text
 import email.utils
 
+logger = logging.getLogger(__name__)
+
 
 class Mailer(object):
     def send(self, msg):
         raise NotImplementedError
 
     def msg_plain(self, from_email, to_email, subject, body):
-        msg = email.mime.text.MIMEText(body, 'plain', 'utf_8')
+        msg = email.mime.text.MIMEText(body, 'plain', 'utf-8')
         msg['Subject'] = subject
         msg['From'] = from_email
         msg['To'] = to_email
@@ -62,15 +65,16 @@ class Mailer(object):
         msg['To'] = to_email
         msg['Date'] = email.utils.formatdate()
 
-        msg.attach(email.mime.text.MIMEText(body_text, 'plain', 'utf_8'))
-        msg.attach(email.mime.text.MIMEText(body_html, 'html', 'utf_8'))
+        msg.attach(email.mime.text.MIMEText(body_text, 'plain', 'utf-8'))
+        msg.attach(email.mime.text.MIMEText(body_html, 'html', 'utf-8'))
 
         return msg
 
 
 class SMTPMailer(Mailer):
-    def __init__(self, smtp_server, smtp_port, tls, auth):
+    def __init__(self, smtp_user, smtp_server, smtp_port, tls, auth):
         self.smtp_server = smtp_server
+        self.smtp_user = smtp_user
         self.smtp_port = smtp_port
         self.tls = tls
         self.auth = auth
@@ -83,10 +87,10 @@ class SMTPMailer(Mailer):
             s.starttls()
 
         if self.auth and keyring is not None:
-            passwd = keyring.get_password(self.smtp_server, msg['From'])
+            passwd = keyring.get_password(self.smtp_server, self.smtp_user)
             if passwd is None:
-                raise ValueError('No password available in keyring for {}, {}'.format(self.smtp_server, msg['From']))
-            s.login(msg['From'], passwd)
+                raise ValueError('No password available in keyring for {}, {}'.format(self.smtp_server, self.smtp_user))
+            s.login(self.smtp_user, passwd)
 
         s.sendmail(msg['From'], [msg['To']], msg.as_string())
         s.quit()
@@ -106,6 +110,10 @@ class SendmailMailer(Mailer):
             logger.error('Sendmail failed with {result}'.format(result=result))
 
 
+def have_password(smtp_server, from_email):
+    return keyring.get_password(smtp_server, from_email) is not None
+
+
 def set_password(smtp_server, from_email):
     ''' Set the keyring password for the mail connection. Interactive.'''
     if keyring is None:
