@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 #
 # This file is part of urlwatch (https://thp.io/2008/urlwatch/).
-# Copyright (c) 2008-2016 Thomas Perl <thp.io/about>
+# Copyright (c) 2008-2018 Thomas Perl <m@thp.io>
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -92,6 +92,8 @@ DEFAULT_CONFIG = {
         'pushover': {
             'enabled': False,
             'app': '',
+            'device': '',
+            'sound': 'spacealarm',
             'user': '',
         },
         'pushbullet': {
